# Copyright 2014-2017 Intel Corporation
# All Rights Reserved.
#
# If this  software was obtained  under the  Intel Simplified  Software License,
# the following terms apply:
#
# The source code,  information  and material  ("Material") contained  herein is
# owned by Intel Corporation or its  suppliers or licensors,  and  title to such
# Material remains with Intel  Corporation or its  suppliers or  licensors.  The
# Material  contains  proprietary  information  of  Intel or  its suppliers  and
# licensors.  The Material is protected by  worldwide copyright  laws and treaty
# provisions.  No part  of  the  Material   may  be  used,  copied,  reproduced,
# modified, published,  uploaded, posted, transmitted,  distributed or disclosed
# in any way without Intel's prior express written permission.  No license under
# any patent,  copyright or other  intellectual property rights  in the Material
# is granted to  or  conferred  upon  you,  either   expressly,  by implication,
# inducement,  estoppel  or  otherwise.  Any  license   under such  intellectual
# property rights must be express and approved by Intel in writing.
#
# Unless otherwise agreed by Intel in writing,  you may not remove or alter this
# notice or  any  other  notice   embedded  in  Materials  by  Intel  or Intel's
# suppliers or licensors in any way.
#
#
# If this  software  was obtained  under the  Apache License,  Version  2.0 (the
# "License"), the following terms apply:
#
# You may  not use this  file except  in compliance  with  the License.  You may
# obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless  required  by   applicable  law  or  agreed  to  in  writing,  software
# distributed under the License  is distributed  on an  "AS IS"  BASIS,  WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#
# See the   License  for the   specific  language   governing   permissions  and
# limitations under the License.


from sys import version_info
if version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_iterative_solver', [dirname(__file__)])
        except ImportError:
            import _iterative_solver
            return _iterative_solver
        if fp is not None:
            try:
                _mod = imp.load_module('_iterative_solver', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _iterative_solver = swig_import_helper()
    del swig_import_helper
else:
    import _iterative_solver
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0


import daal.algorithms.optimization_solver
import daal.algorithms
import daal.data_management
import daal
import daal.services
import daal.data_management.data_feature_utils
import sys
daal.algorithms.optimization_solver = sys.modules[__package__]
del sys


_iterative_solver.inputArgument_swigconstant(_iterative_solver)
inputArgument = _iterative_solver.inputArgument

_iterative_solver.lastInputId_swigconstant(_iterative_solver)
lastInputId = _iterative_solver.lastInputId

_iterative_solver.optionalArgument_swigconstant(_iterative_solver)
optionalArgument = _iterative_solver.optionalArgument

_iterative_solver.lastOptionalInputId_swigconstant(_iterative_solver)
lastOptionalInputId = _iterative_solver.lastOptionalInputId

_iterative_solver.minimum_swigconstant(_iterative_solver)
minimum = _iterative_solver.minimum

_iterative_solver.nIterations_swigconstant(_iterative_solver)
nIterations = _iterative_solver.nIterations

_iterative_solver.lastResultId_swigconstant(_iterative_solver)
lastResultId = _iterative_solver.lastResultId

_iterative_solver.optionalResult_swigconstant(_iterative_solver)
optionalResult = _iterative_solver.optionalResult

_iterative_solver.lastOptionalResultId_swigconstant(_iterative_solver)
lastOptionalResultId = _iterative_solver.lastOptionalResultId

_iterative_solver.lastIteration_swigconstant(_iterative_solver)
lastIteration = _iterative_solver.lastIteration

_iterative_solver.lastOptionalData_swigconstant(_iterative_solver)
lastOptionalData = _iterative_solver.lastOptionalData
class Parameter(daal.algorithms.Parameter):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.Parameter]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Parameter, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.Parameter]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Parameter, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _iterative_solver.new_Parameter(*args)
        try:
            self.this.append(this)
        except:
            self.this = this
    __swig_destroy__ = _iterative_solver.delete_Parameter
    __del__ = lambda self: None

    def check(self):
        return _iterative_solver.Parameter_check(self)
    __swig_setmethods__["function"] = _iterative_solver.Parameter_function_set
    __swig_getmethods__["function"] = _iterative_solver.Parameter_function_get
    if _newclass:
        function = _swig_property(_iterative_solver.Parameter_function_get, _iterative_solver.Parameter_function_set)
    __swig_setmethods__["nIterations"] = _iterative_solver.Parameter_nIterations_set
    __swig_getmethods__["nIterations"] = _iterative_solver.Parameter_nIterations_get
    if _newclass:
        nIterations = _swig_property(_iterative_solver.Parameter_nIterations_get, _iterative_solver.Parameter_nIterations_set)
    __swig_setmethods__["accuracyThreshold"] = _iterative_solver.Parameter_accuracyThreshold_set
    __swig_getmethods__["accuracyThreshold"] = _iterative_solver.Parameter_accuracyThreshold_get
    if _newclass:
        accuracyThreshold = _swig_property(_iterative_solver.Parameter_accuracyThreshold_get, _iterative_solver.Parameter_accuracyThreshold_set)
    __swig_setmethods__["optionalResultRequired"] = _iterative_solver.Parameter_optionalResultRequired_set
    __swig_getmethods__["optionalResultRequired"] = _iterative_solver.Parameter_optionalResultRequired_get
    if _newclass:
        optionalResultRequired = _swig_property(_iterative_solver.Parameter_optionalResultRequired_get, _iterative_solver.Parameter_optionalResultRequired_set)
    __swig_setmethods__["batchSize"] = _iterative_solver.Parameter_batchSize_set
    __swig_getmethods__["batchSize"] = _iterative_solver.Parameter_batchSize_get
    if _newclass:
        batchSize = _swig_property(_iterative_solver.Parameter_batchSize_get, _iterative_solver.Parameter_batchSize_set)
Parameter_swigregister = _iterative_solver.Parameter_swigregister
Parameter_swigregister(Parameter)

class Input(daal.algorithms.Input):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.Input]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Input, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.Input]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Input, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _iterative_solver.new_Input(*args)
        try:
            self.this.append(this)
        except:
            self.this = this
    __swig_destroy__ = _iterative_solver.delete_Input
    __del__ = lambda self: None

    def getInput(self, id):
        return _iterative_solver.Input_getInput(self, id)

    def getOptionalInput(self, id):
        return _iterative_solver.Input_getOptionalInput(self, id)

    def get(self, id):
        return _iterative_solver.Input_get(self, id)

    def setInput(self, id, ptr):
        return _iterative_solver.Input_setInput(self, id, ptr)

    def setOptionalInput(self, id, ptr):
        return _iterative_solver.Input_setOptionalInput(self, id, ptr)

    def set(self, id, ptr):
        return _iterative_solver.Input_set(self, id, ptr)

    def check(self, par, method):
        return _iterative_solver.Input_check(self, par, method)
Input_swigregister = _iterative_solver.Input_swigregister
Input_swigregister(Input)

class Result(daal.algorithms.Result):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.Result]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Result, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.Result]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Result, name)
    __repr__ = _swig_repr
    __swig_getmethods__["serializationTag"] = lambda x: _iterative_solver.Result_serializationTag
    if _newclass:
        serializationTag = staticmethod(_iterative_solver.Result_serializationTag)

    def getSerializationTag(self):
        return _iterative_solver.Result_getSerializationTag(self)

    def __init__(self):
        this = _iterative_solver.new_Result()
        try:
            self.this.append(this)
        except:
            self.this = this
    __swig_destroy__ = _iterative_solver.delete_Result
    __del__ = lambda self: None

    def getResult(self, id):
        return _iterative_solver.Result_getResult(self, id)

    def getOptionalResult(self, id):
        return _iterative_solver.Result_getOptionalResult(self, id)

    def get(self, id):
        return _iterative_solver.Result_get(self, id)

    def setResult(self, id, ptr):
        return _iterative_solver.Result_setResult(self, id, ptr)

    def setOptionalResult(self, id, ptr):
        return _iterative_solver.Result_setOptionalResult(self, id, ptr)

    def set(self, id, ptr):
        return _iterative_solver.Result_set(self, id, ptr)

    def check(self, input, par, method):
        return _iterative_solver.Result_check(self, input, par, method)

    def allocate_Float64(self, input, par, method):
        r"""
This function is specialized for float64"""
        return _iterative_solver.Result_allocate_Float64(self, input, par, method)


    def allocate_Float32(self, input, par, method):
        r"""
This function is specialized for float32"""
        return _iterative_solver.Result_allocate_Float32(self, input, par, method)

Result_swigregister = _iterative_solver.Result_swigregister
Result_swigregister(Result)

def Result_serializationTag():
    return _iterative_solver.Result_serializationTag()
Result_serializationTag = _iterative_solver.Result_serializationTag

class Batch(daal.algorithms.optimization_solver.BatchIface):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.optimization_solver.BatchIface]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Batch, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.optimization_solver.BatchIface]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Batch, name)

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _iterative_solver.delete_Batch
    __del__ = lambda self: None

    def getInput(self):
        return _iterative_solver.Batch_getInput(self)

    def getParameter(self):
        return _iterative_solver.Batch_getParameter(self)

    def getResult(self):
        return _iterative_solver.Batch_getResult(self)

    def createResult(self):
        return _iterative_solver.Batch_createResult(self)

    def clone(self):
        return _iterative_solver.Batch_clone(self)

    def compute(self):
        return _iterative_solver.Batch_compute(self)
Batch_swigregister = _iterative_solver.Batch_swigregister
Batch_swigregister(Batch)

from numpy import float64, float32, intc


# This file is compatible with both classic and new-style classes.


