# Copyright 2014-2017 Intel Corporation
# All Rights Reserved.
#
# If this  software was obtained  under the  Intel Simplified  Software License,
# the following terms apply:
#
# The source code,  information  and material  ("Material") contained  herein is
# owned by Intel Corporation or its  suppliers or licensors,  and  title to such
# Material remains with Intel  Corporation or its  suppliers or  licensors.  The
# Material  contains  proprietary  information  of  Intel or  its suppliers  and
# licensors.  The Material is protected by  worldwide copyright  laws and treaty
# provisions.  No part  of  the  Material   may  be  used,  copied,  reproduced,
# modified, published,  uploaded, posted, transmitted,  distributed or disclosed
# in any way without Intel's prior express written permission.  No license under
# any patent,  copyright or other  intellectual property rights  in the Material
# is granted to  or  conferred  upon  you,  either   expressly,  by implication,
# inducement,  estoppel  or  otherwise.  Any  license   under such  intellectual
# property rights must be express and approved by Intel in writing.
#
# Unless otherwise agreed by Intel in writing,  you may not remove or alter this
# notice or  any  other  notice   embedded  in  Materials  by  Intel  or Intel's
# suppliers or licensors in any way.
#
#
# If this  software  was obtained  under the  Apache License,  Version  2.0 (the
# "License"), the following terms apply:
#
# You may  not use this  file except  in compliance  with  the License.  You may
# obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless  required  by   applicable  law  or  agreed  to  in  writing,  software
# distributed under the License  is distributed  on an  "AS IS"  BASIS,  WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#
# See the   License  for the   specific  language   governing   permissions  and
# limitations under the License.


from sys import version_info
if version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_db', [dirname(__file__)])
        except ImportError:
            import _db
            return _db
        if fp is not None:
            try:
                _mod = imp.load_module('_db', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _db = swig_import_helper()
    del swig_import_helper
else:
    import _db
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0


import daal.data_management
import daal
import daal.services
import daal.data_management.data_feature_utils
class MySQLFeatureManager(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MySQLFeatureManager, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MySQLFeatureManager, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _db.new_MySQLFeatureManager()
        try:
            self.this.append(this)
        except:
            self.this = this

    def statementResultsNumericTable(self, hdlStmt, nt, maxRows):
        return _db.MySQLFeatureManager_statementResultsNumericTable(self, hdlStmt, nt, maxRows)

    def createDictionary(self, hdlStmt, dict):
        return _db.MySQLFeatureManager_createDictionary(self, hdlStmt, dict)

    def setLimitQuery(self, query, idx_last_read, maxRows):
        return _db.MySQLFeatureManager_setLimitQuery(self, query, idx_last_read, maxRows)

    def getErrors(self):
        return _db.MySQLFeatureManager_getErrors(self)
    __swig_destroy__ = _db.delete_MySQLFeatureManager
    __del__ = lambda self: None
MySQLFeatureManager_swigregister = _db.MySQLFeatureManager_swigregister
MySQLFeatureManager_swigregister(MySQLFeatureManager)

class ODBCDataSource_MySQLFeatureManagerFloat64(daal.data_management.DataSourceTemplate_HomogenNumericTable_Float64Float64):
    r"""
This class is an alias of ODBCDataSource(FeatureManager=daal.data_management.MySQLFeatureManager, StatsType=float64)
    """
    __swig_setmethods__ = {}
    for _s in [daal.data_management.DataSourceTemplate_HomogenNumericTable_Float64Float64]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, ODBCDataSource_MySQLFeatureManagerFloat64, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.data_management.DataSourceTemplate_HomogenNumericTable_Float64Float64]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, ODBCDataSource_MySQLFeatureManagerFloat64, name)
    __repr__ = _swig_repr

    def checkDictionary(self):
        return _db.ODBCDataSource_MySQLFeatureManagerFloat64_checkDictionary(self)

    def checkNumericTable(self):
        return _db.ODBCDataSource_MySQLFeatureManagerFloat64_checkNumericTable(self)

    def freeNumericTable(self):
        return _db.ODBCDataSource_MySQLFeatureManagerFloat64_freeNumericTable(self)
    __swig_setmethods__["_dict"] = _db.ODBCDataSource_MySQLFeatureManagerFloat64__dict_set
    __swig_getmethods__["_dict"] = _db.ODBCDataSource_MySQLFeatureManagerFloat64__dict_get
    if _newclass:
        _dict = _swig_property(_db.ODBCDataSource_MySQLFeatureManagerFloat64__dict_get, _db.ODBCDataSource_MySQLFeatureManagerFloat64__dict_set)
    __swig_setmethods__["_initialMaxRows"] = _db.ODBCDataSource_MySQLFeatureManagerFloat64__initialMaxRows_set
    __swig_getmethods__["_initialMaxRows"] = _db.ODBCDataSource_MySQLFeatureManagerFloat64__initialMaxRows_get
    if _newclass:
        _initialMaxRows = _swig_property(_db.ODBCDataSource_MySQLFeatureManagerFloat64__initialMaxRows_get, _db.ODBCDataSource_MySQLFeatureManagerFloat64__initialMaxRows_set)

    def __init__(self, *args):
        this = _db.new_ODBCDataSource_MySQLFeatureManagerFloat64(*args)
        try:
            self.this.append(this)
        except:
            self.this = this
    __swig_destroy__ = _db.delete_ODBCDataSource_MySQLFeatureManagerFloat64
    __del__ = lambda self: None

    def freeHandles(self):
        return _db.ODBCDataSource_MySQLFeatureManagerFloat64_freeHandles(self)

    def loadDataBlock(self, *args):
        return _db.ODBCDataSource_MySQLFeatureManagerFloat64_loadDataBlock(self, *args)

    def createDictionaryFromContext(self):
        return _db.ODBCDataSource_MySQLFeatureManagerFloat64_createDictionaryFromContext(self)

    def getStatus(self):
        return _db.ODBCDataSource_MySQLFeatureManagerFloat64_getStatus(self)

    def getNumberOfAvailableRows(self):
        return _db.ODBCDataSource_MySQLFeatureManagerFloat64_getNumberOfAvailableRows(self)

    def getFeatureManager(self):
        return _db.ODBCDataSource_MySQLFeatureManagerFloat64_getFeatureManager(self)
ODBCDataSource_MySQLFeatureManagerFloat64_swigregister = _db.ODBCDataSource_MySQLFeatureManagerFloat64_swigregister
ODBCDataSource_MySQLFeatureManagerFloat64_swigregister(ODBCDataSource_MySQLFeatureManagerFloat64)

from numpy import float64, float32, intc

class ODBCDataSource(object):
    r"""Factory class for different types of ODBCDataSource."""
    def __new__(cls,
                *args, **kwargs):
        if 'FeatureManager' not in kwargs or kwargs['FeatureManager'] == daal.data_management.MySQLFeatureManager:
            if 'StatsType' not in kwargs or kwargs['StatsType'] == float64:
                return ODBCDataSource_MySQLFeatureManagerFloat64(*args)

        raise RuntimeError("No appropriate constructor found for ODBCDataSource")


# This file is compatible with both classic and new-style classes.


