/* file: gc_sharedptr.h */
/*******************************************************************************
* Copyright 2014-2017 Intel Corporation
* All Rights Reserved.
*
* If this  software was obtained  under the  Intel Simplified  Software License,
* the following terms apply:
*
* The source code,  information  and material  ("Material") contained  herein is
* owned by Intel Corporation or its  suppliers or licensors,  and  title to such
* Material remains with Intel  Corporation or its  suppliers or  licensors.  The
* Material  contains  proprietary  information  of  Intel or  its suppliers  and
* licensors.  The Material is protected by  worldwide copyright  laws and treaty
* provisions.  No part  of  the  Material   may  be  used,  copied,  reproduced,
* modified, published,  uploaded, posted, transmitted,  distributed or disclosed
* in any way without Intel's prior express written permission.  No license under
* any patent,  copyright or other  intellectual property rights  in the Material
* is granted to  or  conferred  upon  you,  either   expressly,  by implication,
* inducement,  estoppel  or  otherwise.  Any  license   under such  intellectual
* property rights must be express and approved by Intel in writing.
*
* Unless otherwise agreed by Intel in writing,  you may not remove or alter this
* notice or  any  other  notice   embedded  in  Materials  by  Intel  or Intel's
* suppliers or licensors in any way.
*
*
* If this  software  was obtained  under the  Apache License,  Version  2.0 (the
* "License"), the following terms apply:
*
* You may  not use this  file except  in compliance  with  the License.  You may
* obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
*
*
* Unless  required  by   applicable  law  or  agreed  to  in  writing,  software
* distributed under the License  is distributed  on an  "AS IS"  BASIS,  WITHOUT
* WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*
* See the   License  for the   specific  language   governing   permissions  and
* limitations under the License.
*******************************************************************************/

/*
//++
//  Implementation garbage collection hooks for numpy arrays passed to Intel(R) DAAL.
//--
*/

#ifndef __GC_SHAREDPTR_INCLUDED__
#define __GC_SHAREDPTR_INCLUDED__

#include <map>
#include <vector>
#include <services/daal_shared_ptr.h>

typedef std::vector< const PyObject * > gco_vec;
typedef std::map< const void*, gco_vec > gc_map;
static gc_map _pa_map;

static void increment_py_ref(const void *tbl, PyObject * obj) {
    if( ! obj ) return;
    SWIG_PYTHON_THREAD_BEGIN_BLOCK;
    Py_INCREF( obj );
    _pa_map[tbl].push_back(obj);
    SWIG_PYTHON_THREAD_END_BLOCK;
}

static void decrement_py_ref(const void * tbl) {
    SWIG_PYTHON_THREAD_BEGIN_BLOCK;
    gc_map::iterator it = _pa_map.find(tbl);
    if (it != _pa_map.end()) {
        for( gco_vec::iterator i = it->second.begin(); i != it->second.end(); ++i ) {
            Py_DECREF(*i);
        }
        _pa_map.erase(it);
    }
    SWIG_PYTHON_THREAD_END_BLOCK;
}

template<typename T>
static void decrement_py_ref_and_delete(const T * tbl) {
    decrement_py_ref(tbl);
    delete tbl;
}

#endif // __GC_SHAREDPTR_INCLUDED__
