#! /usr/bin/env python
################################################################################
# Copyright 2014-2017 Intel Corporation
# All Rights Reserved.
#
# If this  software was obtained  under the  Intel Simplified  Software License,
# the following terms apply:
#
# The source code,  information  and material  ("Material") contained  herein is
# owned by Intel Corporation or its  suppliers or licensors,  and  title to such
# Material remains with Intel  Corporation or its  suppliers or  licensors.  The
# Material  contains  proprietary  information  of  Intel or  its suppliers  and
# licensors.  The Material is protected by  worldwide copyright  laws and treaty
# provisions.  No part  of  the  Material   may  be  used,  copied,  reproduced,
# modified, published,  uploaded, posted, transmitted,  distributed or disclosed
# in any way without Intel's prior express written permission.  No license under
# any patent,  copyright or other  intellectual property rights  in the Material
# is granted to  or  conferred  upon  you,  either   expressly,  by implication,
# inducement,  estoppel  or  otherwise.  Any  license   under such  intellectual
# property rights must be express and approved by Intel in writing.
#
# Unless otherwise agreed by Intel in writing,  you may not remove or alter this
# notice or  any  other  notice   embedded  in  Materials  by  Intel  or Intel's
# suppliers or licensors in any way.
#
#
# If this  software  was obtained  under the  Apache License,  Version  2.0 (the
# "License"), the following terms apply:
#
# You may  not use this  file except  in compliance  with  the License.  You may
# obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless  required  by   applicable  law  or  agreed  to  in  writing,  software
# distributed under the License  is distributed  on an  "AS IS"  BASIS,  WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#
# See the   License  for the   specific  language   governing   permissions  and
# limitations under the License.
################################################################################


# System imports
import os
import subprocess
import sys
from distutils.core import *
from distutils      import sysconfig
from setuptools     import setup, Extension
from os.path import join as jp
from distutils.sysconfig import get_config_vars

import numpy as np

npyver = int(np.__version__.split('.')[1])

if npyver == 9:
    print("Warning:  Detected numpy version {}".format(np.__version__))
    print("Numpy 1.10 or greater is strongly recommended.")
    print("Earlier versions have not been tested. Use at your own risk.")

if npyver < 9:
    sys.exit("Error: Detected numpy {}. The minimum requirement is 1.9, and >= 1.10 is strongly recommended".format(np.__version__))


daal_root=os.environ['DAALROOT']
IS_WIN = False
IS_MAC = False
IS_LIN = False

if 'linux' in sys.platform:
    IS_LIN = True
    lib_dir = '/lib/intel64_lin'
elif sys.platform == 'darwin':
    IS_MAC = True
    lib_dir = '/lib'
elif sys.platform in ['win32', 'cygwin']:
    IS_WIN = True
    lib_dir = '/lib/intel64_win'
else:
    assert False, sys.platform + ' not supported'

DAAL_DEFAULT_TYPE = 'double'

all_modules = {
        'daal.algorithms': '_algorithms',
        'daal.algorithms.adaboost': '_adaboost',
        'daal.algorithms.adaboost.prediction': '_prediction',
        'daal.algorithms.adaboost.quality_metric_set': '_quality_metric_set',
        'daal.algorithms.adaboost.training': '_training',
        'daal.algorithms.association_rules': '_association_rules',
        'daal.algorithms.bacon_outlier_detection': '_bacon_outlier_detection',
        'daal.algorithms.boosting': '_boosting',
        'daal.algorithms.boosting.prediction': '_prediction1',
        'daal.algorithms.boosting.training': '_training1',
        'daal.algorithms.brownboost': '_brownboost',
        'daal.algorithms.brownboost.prediction': '_prediction2',
        'daal.algorithms.brownboost.quality_metric_set': '_quality_metric_set1',
        'daal.algorithms.brownboost.training': '_training2',
        'daal.algorithms.cholesky': '_cholesky',
        'daal.algorithms.classifier': '_classifier',
        'daal.algorithms.classifier.prediction': '_prediction3',
        'daal.algorithms.classifier.quality_metric.binary_confusion_matrix': '_binary_confusion_matrix',
        'daal.algorithms.classifier.quality_metric.multiclass_confusion_matrix': '_multiclass_confusion_matrix',
        'daal.algorithms.classifier.training': '_training3',
        'daal.algorithms.correlation_distance': '_correlation_distance',
        'daal.algorithms.cosine_distance': '_cosine_distance',
        'daal.algorithms.covariance': '_covariance',
        'daal.algorithms.decision_forest': '_decision_forest',
        'daal.algorithms.decision_forest.classification': '_classification',
        'daal.algorithms.decision_forest.classification.prediction': '_prediction4',
        'daal.algorithms.decision_forest.classification.training': '_training4',
        'daal.algorithms.decision_forest.regression': '_regression',
        'daal.algorithms.decision_forest.regression.prediction': '_prediction5',
        'daal.algorithms.decision_forest.regression.training': '_training5',
        'daal.algorithms.decision_forest.training': '_training6',
        'daal.algorithms.decision_tree': '_decision_tree',
        'daal.algorithms.decision_tree.classification': '_classification1',
        'daal.algorithms.decision_tree.classification.prediction': '_prediction6',
        'daal.algorithms.decision_tree.classification.training': '_training7',
        'daal.algorithms.decision_tree.regression': '_regression1',
        'daal.algorithms.decision_tree.regression.prediction': '_prediction7',
        'daal.algorithms.decision_tree.regression.training': '_training8',
        'daal.algorithms.distributions': '_distributions',
        'daal.algorithms.distributions.bernoulli': '_bernoulli',
        'daal.algorithms.distributions.normal': '_normal',
        'daal.algorithms.distributions.uniform': '_uniform',
        'daal.algorithms.em_gmm': '_em_gmm',
        'daal.algorithms.em_gmm.init': '_init',
        'daal.algorithms.engines': '_engines',
        'daal.algorithms.engines.mt19937': '_mt19937',
        'daal.algorithms.implicit_als': '_implicit_als',
        'daal.algorithms.implicit_als.prediction.ratings': '_ratings',
        'daal.algorithms.implicit_als.training': '_training9',
        'daal.algorithms.implicit_als.training.init': '_init1',
        'daal.algorithms.kdtree_knn_classification': '_kdtree_knn_classification',
        'daal.algorithms.kdtree_knn_classification.prediction': '_prediction8',
        'daal.algorithms.kdtree_knn_classification.training': '_training10',
        'daal.algorithms.kernel_function': '_kernel_function',
        'daal.algorithms.kernel_function.linear': '_linear',
        'daal.algorithms.kernel_function.rbf': '_rbf',
        'daal.algorithms.kmeans': '_kmeans',
        'daal.algorithms.kmeans.init': '_init2',
        'daal.algorithms.linear_model': '_linear_model',
        'daal.algorithms.linear_model.prediction': '_prediction9',
        'daal.algorithms.linear_model.training': '_training11',
        'daal.algorithms.linear_regression': '_linear_regression',
        'daal.algorithms.linear_regression.prediction': '_prediction10',
        'daal.algorithms.linear_regression.quality_metric.group_of_betas': '_group_of_betas',
        'daal.algorithms.linear_regression.quality_metric.single_beta': '_single_beta',
        'daal.algorithms.linear_regression.quality_metric_set': '_quality_metric_set2',
        'daal.algorithms.linear_regression.training': '_training12',
        'daal.algorithms.logitboost': '_logitboost',
        'daal.algorithms.logitboost.prediction': '_prediction11',
        'daal.algorithms.logitboost.quality_metric_set': '_quality_metric_set3',
        'daal.algorithms.logitboost.training': '_training13',
        'daal.algorithms.low_order_moments': '_low_order_moments',
        'daal.algorithms.math.abs': '_abs',
        'daal.algorithms.math.logistic': '_logistic',
        'daal.algorithms.math.relu': '_relu',
        'daal.algorithms.math.smoothrelu': '_smoothrelu',
        'daal.algorithms.math.softmax': '_softmax',
        'daal.algorithms.math.tanh': '_tanh',
        'daal.algorithms.multi_class_classifier': '_multi_class_classifier',
        'daal.algorithms.multi_class_classifier.prediction': '_prediction12',
        'daal.algorithms.multi_class_classifier.quality_metric_set': '_quality_metric_set4',
        'daal.algorithms.multi_class_classifier.training': '_training14',
        'daal.algorithms.multinomial_naive_bayes': '_multinomial_naive_bayes',
        'daal.algorithms.multinomial_naive_bayes.prediction': '_prediction13',
        'daal.algorithms.multinomial_naive_bayes.quality_metric_set': '_quality_metric_set5',
        'daal.algorithms.multinomial_naive_bayes.training': '_training15',
        'daal.algorithms.multivariate_outlier_detection': '_multivariate_outlier_detection',
        'daal.algorithms.neural_networks': '_neural_networks',
        'daal.algorithms.neural_networks.initializers': '_initializers',
        'daal.algorithms.neural_networks.initializers.gaussian': '_gaussian',
        'daal.algorithms.neural_networks.initializers.truncated_gaussian': '_truncated_gaussian',
        'daal.algorithms.neural_networks.initializers.uniform': '_uniform1',
        'daal.algorithms.neural_networks.initializers.xavier': '_xavier',
        'daal.algorithms.neural_networks.layers': '_layers',
        'daal.algorithms.neural_networks.layers.abs': '_abs1',
        'daal.algorithms.neural_networks.layers.abs.backward': '_backward',
        'daal.algorithms.neural_networks.layers.abs.forward': '_forward',
        'daal.algorithms.neural_networks.layers.average_pooling1d': '_average_pooling1d',
        'daal.algorithms.neural_networks.layers.average_pooling1d.backward': '_backward1',
        'daal.algorithms.neural_networks.layers.average_pooling1d.forward': '_forward1',
        'daal.algorithms.neural_networks.layers.average_pooling2d': '_average_pooling2d',
        'daal.algorithms.neural_networks.layers.average_pooling2d.backward': '_backward2',
        'daal.algorithms.neural_networks.layers.average_pooling2d.forward': '_forward2',
        'daal.algorithms.neural_networks.layers.average_pooling3d': '_average_pooling3d',
        'daal.algorithms.neural_networks.layers.average_pooling3d.backward': '_backward3',
        'daal.algorithms.neural_networks.layers.average_pooling3d.forward': '_forward3',
        'daal.algorithms.neural_networks.layers.backward': '_backward4',
        'daal.algorithms.neural_networks.layers.batch_normalization': '_batch_normalization',
        'daal.algorithms.neural_networks.layers.batch_normalization.backward': '_backward5',
        'daal.algorithms.neural_networks.layers.batch_normalization.forward': '_forward4',
        'daal.algorithms.neural_networks.layers.concat': '_concat',
        'daal.algorithms.neural_networks.layers.concat.backward': '_backward6',
        'daal.algorithms.neural_networks.layers.concat.forward': '_forward5',
        'daal.algorithms.neural_networks.layers.convolution2d': '_convolution2d',
        'daal.algorithms.neural_networks.layers.convolution2d.backward': '_backward7',
        'daal.algorithms.neural_networks.layers.convolution2d.forward': '_forward6',
        'daal.algorithms.neural_networks.layers.dropout': '_dropout',
        'daal.algorithms.neural_networks.layers.dropout.backward': '_backward8',
        'daal.algorithms.neural_networks.layers.dropout.forward': '_forward7',
        'daal.algorithms.neural_networks.layers.eltwise_sum': '_eltwise_sum',
        'daal.algorithms.neural_networks.layers.eltwise_sum.backward': '_backward9',
        'daal.algorithms.neural_networks.layers.eltwise_sum.forward': '_forward8',
        'daal.algorithms.neural_networks.layers.forward': '_forward9',
        'daal.algorithms.neural_networks.layers.fullyconnected': '_fullyconnected',
        'daal.algorithms.neural_networks.layers.fullyconnected.backward': '_backward10',
        'daal.algorithms.neural_networks.layers.fullyconnected.forward': '_forward10',
        'daal.algorithms.neural_networks.layers.lcn': '_lcn',
        'daal.algorithms.neural_networks.layers.lcn.backward': '_backward11',
        'daal.algorithms.neural_networks.layers.lcn.forward': '_forward11',
        'daal.algorithms.neural_networks.layers.locallyconnected2d': '_locallyconnected2d',
        'daal.algorithms.neural_networks.layers.locallyconnected2d.backward': '_backward12',
        'daal.algorithms.neural_networks.layers.locallyconnected2d.forward': '_forward12',
        'daal.algorithms.neural_networks.layers.logistic': '_logistic1',
        'daal.algorithms.neural_networks.layers.logistic.backward': '_backward13',
        'daal.algorithms.neural_networks.layers.logistic.forward': '_forward13',
        'daal.algorithms.neural_networks.layers.loss': '_loss',
        'daal.algorithms.neural_networks.layers.loss.backward': '_backward14',
        'daal.algorithms.neural_networks.layers.loss.forward': '_forward14',
        'daal.algorithms.neural_networks.layers.loss.logistic_cross': '_logistic_cross',
        'daal.algorithms.neural_networks.layers.loss.logistic_cross.backward': '_backward15',
        'daal.algorithms.neural_networks.layers.loss.logistic_cross.forward': '_forward15',
        'daal.algorithms.neural_networks.layers.loss.softmax_cross': '_softmax_cross',
        'daal.algorithms.neural_networks.layers.loss.softmax_cross.backward': '_backward16',
        'daal.algorithms.neural_networks.layers.loss.softmax_cross.forward': '_forward16',
        'daal.algorithms.neural_networks.layers.lrn': '_lrn',
        'daal.algorithms.neural_networks.layers.lrn.backward': '_backward17',
        'daal.algorithms.neural_networks.layers.lrn.forward': '_forward17',
        'daal.algorithms.neural_networks.layers.maximum_pooling1d': '_maximum_pooling1d',
        'daal.algorithms.neural_networks.layers.maximum_pooling1d.backward': '_backward18',
        'daal.algorithms.neural_networks.layers.maximum_pooling1d.forward': '_forward18',
        'daal.algorithms.neural_networks.layers.maximum_pooling2d': '_maximum_pooling2d',
        'daal.algorithms.neural_networks.layers.maximum_pooling2d.backward': '_backward19',
        'daal.algorithms.neural_networks.layers.maximum_pooling2d.forward': '_forward19',
        'daal.algorithms.neural_networks.layers.maximum_pooling3d': '_maximum_pooling3d',
        'daal.algorithms.neural_networks.layers.maximum_pooling3d.backward': '_backward20',
        'daal.algorithms.neural_networks.layers.maximum_pooling3d.forward': '_forward20',
        'daal.algorithms.neural_networks.layers.pooling1d': '_pooling1d',
        'daal.algorithms.neural_networks.layers.pooling1d.backward': '_backward21',
        'daal.algorithms.neural_networks.layers.pooling1d.forward': '_forward21',
        'daal.algorithms.neural_networks.layers.pooling2d': '_pooling2d',
        'daal.algorithms.neural_networks.layers.pooling2d.backward': '_backward22',
        'daal.algorithms.neural_networks.layers.pooling2d.forward': '_forward22',
        'daal.algorithms.neural_networks.layers.pooling3d': '_pooling3d',
        'daal.algorithms.neural_networks.layers.pooling3d.backward': '_backward23',
        'daal.algorithms.neural_networks.layers.pooling3d.forward': '_forward23',
        'daal.algorithms.neural_networks.layers.prelu': '_prelu',
        'daal.algorithms.neural_networks.layers.prelu.backward': '_backward24',
        'daal.algorithms.neural_networks.layers.prelu.forward': '_forward24',
        'daal.algorithms.neural_networks.layers.relu': '_relu1',
        'daal.algorithms.neural_networks.layers.relu.backward': '_backward25',
        'daal.algorithms.neural_networks.layers.relu.forward': '_forward25',
        'daal.algorithms.neural_networks.layers.reshape': '_reshape',
        'daal.algorithms.neural_networks.layers.reshape.backward': '_backward26',
        'daal.algorithms.neural_networks.layers.reshape.forward': '_forward26',
        'daal.algorithms.neural_networks.layers.smoothrelu': '_smoothrelu1',
        'daal.algorithms.neural_networks.layers.smoothrelu.backward': '_backward27',
        'daal.algorithms.neural_networks.layers.smoothrelu.forward': '_forward27',
        'daal.algorithms.neural_networks.layers.softmax': '_softmax1',
        'daal.algorithms.neural_networks.layers.softmax.backward': '_backward28',
        'daal.algorithms.neural_networks.layers.softmax.forward': '_forward28',
        'daal.algorithms.neural_networks.layers.spatial_average_pooling2d': '_spatial_average_pooling2d',
        'daal.algorithms.neural_networks.layers.spatial_average_pooling2d.backward': '_backward29',
        'daal.algorithms.neural_networks.layers.spatial_average_pooling2d.forward': '_forward29',
        'daal.algorithms.neural_networks.layers.spatial_maximum_pooling2d': '_spatial_maximum_pooling2d',
        'daal.algorithms.neural_networks.layers.spatial_maximum_pooling2d.backward': '_backward30',
        'daal.algorithms.neural_networks.layers.spatial_maximum_pooling2d.forward': '_forward30',
        'daal.algorithms.neural_networks.layers.spatial_pooling2d': '_spatial_pooling2d',
        'daal.algorithms.neural_networks.layers.spatial_pooling2d.backward': '_backward31',
        'daal.algorithms.neural_networks.layers.spatial_pooling2d.forward': '_forward31',
        'daal.algorithms.neural_networks.layers.spatial_stochastic_pooling2d': '_spatial_stochastic_pooling2d',
        'daal.algorithms.neural_networks.layers.spatial_stochastic_pooling2d.backward': '_backward32',
        'daal.algorithms.neural_networks.layers.spatial_stochastic_pooling2d.forward': '_forward32',
        'daal.algorithms.neural_networks.layers.split': '_split',
        'daal.algorithms.neural_networks.layers.split.backward': '_backward33',
        'daal.algorithms.neural_networks.layers.split.forward': '_forward33',
        'daal.algorithms.neural_networks.layers.stochastic_pooling2d': '_stochastic_pooling2d',
        'daal.algorithms.neural_networks.layers.stochastic_pooling2d.backward': '_backward34',
        'daal.algorithms.neural_networks.layers.stochastic_pooling2d.forward': '_forward34',
        'daal.algorithms.neural_networks.layers.tanh': '_tanh1',
        'daal.algorithms.neural_networks.layers.tanh.backward': '_backward35',
        'daal.algorithms.neural_networks.layers.tanh.forward': '_forward35',
        'daal.algorithms.neural_networks.layers.transposed_conv2d': '_transposed_conv2d',
        'daal.algorithms.neural_networks.layers.transposed_conv2d.backward': '_backward36',
        'daal.algorithms.neural_networks.layers.transposed_conv2d.forward': '_forward36',
        'daal.algorithms.neural_networks.prediction': '_prediction14',
        'daal.algorithms.neural_networks.training': '_training16',
        'daal.algorithms.normalization.minmax': '_minmax',
        'daal.algorithms.normalization.zscore': '_zscore',
        'daal.algorithms.optimization_solver': '_optimization_solver',
        'daal.algorithms.optimization_solver.adagrad': '_adagrad',
        'daal.algorithms.optimization_solver.iterative_solver': '_iterative_solver',
        'daal.algorithms.optimization_solver.lbfgs': '_lbfgs',
        'daal.algorithms.optimization_solver.mse': '_mse',
        'daal.algorithms.optimization_solver.objective_function': '_objective_function',
        'daal.algorithms.optimization_solver.precomputed': '_precomputed',
        'daal.algorithms.optimization_solver.sgd': '_sgd',
        'daal.algorithms.optimization_solver.sum_of_functions': '_sum_of_functions',
        'daal.algorithms.pca': '_pca',
        'daal.algorithms.pivoted_qr': '_pivoted_qr',
        'daal.algorithms.qr': '_qr',
        'daal.algorithms.quality_metric': '_quality_metric',
        'daal.algorithms.quality_metric_set': '_quality_metric_set6',
        'daal.algorithms.quantiles': '_quantiles',
        'daal.algorithms.regression': '_regression2',
        'daal.algorithms.regression.prediction': '_prediction15',
        'daal.algorithms.regression.training': '_training17',
        'daal.algorithms.ridge_regression': '_ridge_regression',
        'daal.algorithms.ridge_regression.prediction': '_prediction16',
        'daal.algorithms.ridge_regression.training': '_training18',
        'daal.algorithms.sorting': '_sorting',
        'daal.algorithms.stump': '_stump',
        'daal.algorithms.stump.prediction': '_prediction17',
        'daal.algorithms.stump.training': '_training19',
        'daal.algorithms.svd': '_svd',
        'daal.algorithms.svm': '_svm',
        'daal.algorithms.svm.prediction': '_prediction18',
        'daal.algorithms.svm.quality_metric_set': '_quality_metric_set7',
        'daal.algorithms.svm.training': '_training20',
        'daal.algorithms.univariate_outlier_detection': '_univariate_outlier_detection',
        'daal.algorithms.weak_learner': '_weak_learner',
        'daal.algorithms.weak_learner.prediction': '_prediction19',
        'daal.algorithms.weak_learner.training': '_training21',
        'daal.daal': '_daal',
        'daal.data_management': '_data_management',
        'daal.data_management.data_feature_utils': '_data_feature_utils',
        'daal.data_management.db': '_db',
        'daal.services': '_services',
}

def get_sdl_cflags():
    if IS_LIN or IS_MAC:
        cflags = ['-fstack-protector', '-fPIC', '-D_FORTIFY_SOURCE=2', '-Wformat', '-Wformat-security']
        if IS_LIN:
            return cflags + ['-O2']
        elif IS_MAC:
            return cflags + []
    elif IS_WIN:
        return ['-GS', '-O2']


def get_sdl_ldflags():
    if IS_LIN:
        return ['-Wl,-z,noexecstack', '-Wl,-z,relro', '-Wl,-z,now']
    elif IS_MAC:
        return []
    elif IS_WIN:
        return ['-NXCompat', '-DynamicBase']

def get_type_defines():
    daal_type_defines = ['DAAL_ALGORITHM_FP_TYPE', 'DAAL_SUMMARY_STATISTICS_TYPE', 'DAAL_DATA_TYPE']
    return ["-D{}={}".format(d, DAAL_DEFAULT_TYPE) for d in daal_type_defines]



def getpyexts():
    include_dir_plat = ['./daal/include', daal_root + '/include']
    using_intel = os.environ.get('cc', '') in ['icc', 'icpc', 'icl']
    eca = get_type_defines()
    ela = []

    if using_intel and IS_WIN:
        include_dir_plat.append(jp(os.environ.get('ICPP_COMPILER16', ''), 'compiler', 'include'))
        eca += ['-std=c++11', '-w']
    elif not using_intel and IS_WIN:
        eca += ['-wd4267', '-wd4244', '-wd4101', '-wd4996']
    else:
        eca += ['-std=c++11', '-w']

    # Security flags
    eca += get_sdl_cflags()
    ela += get_sdl_ldflags()

    if sys.version_info[0] >= 3:
        eca.append('-DSWIGPY_USE_CAPSULE_')

    if IS_WIN:
        libraries_plat = ['daal_thread', 'daal_core_dll', 'odbc32']
    else:
        libraries_plat = ['daal_core', 'daal_thread']

    if IS_MAC:
        ela.append('-stdlib=libc++')
        ela.append("-Wl,-rpath,{}".format(jp(daal_root, 'lib')))
        ela.append("-Wl,-rpath,{}".format(jp(daal_root, '..', 'tbb', 'lib')))
    elif IS_WIN:
        ela.append('-IGNORE:4197')

    exts = []
    for m in all_modules:
        stem = m.replace('.', '__')[6:]
        s = m + '.'
        if m in ['daal.daal'] or not any(e.startswith(s) for e in all_modules):
            ext = ".".join([m.rsplit(".",1)[0], all_modules[m]])
        else:
            ext = ".".join([m, all_modules[m]])
        exts.append(Extension(ext,
                              [jp('daal', 'wrp', '_' + stem + '.cpp')],
                              include_dirs=include_dir_plat + [np.get_include()],
                              extra_compile_args=eca,
                              extra_link_args=ela,
                              libraries=libraries_plat,
                              library_dirs=[daal_root + lib_dir],
                              language='c++')),
    return exts

def getpypkgs():
    pkgs = ['daal']
    for m in all_modules:
        s = m + '.'
        if any(e.startswith(s) for e in all_modules):
            pkgs.append(m)
    return pkgs

def getpymods():
    mods = []
    for m in all_modules:
        s = m + '.'
        if m not in ['daal.daal'] and not any(e.startswith(s) for e in all_modules):
            mods.append(m)
    return mods

cfg_vars = get_config_vars()
for key, value in get_config_vars().items():
    if type(value) == str:
        cfg_vars[key] = value.replace("-Wstrict-prototypes", "")

# daal setup
setup(  name        = "pydaal",
        description = "Python API to Intel(R) Data Analytics Acceleration Library (Intel(R) DAAL)",
        author      = "Intel",
        version     = "2018.0.0.20170814",
        classifiers=[
            'Development Status :: 4 - Beta',
            'Environment :: Console',
            'Intended Audience :: Developers',
            'Intended Audience :: System Administrators',
            'Intended Audience :: Other Audience',
            'Intended Audience :: Science/Research',
            'License :: Other/Proprietary License',
            'Operating System :: MacOS :: MacOS X',
            'Operating System :: Microsoft :: Windows',
            'Operating System :: POSIX :: Linux',
            'Programming Language :: Python :: 2.7',
            'Programming Language :: Python :: 3',
            'Topic :: Scientific/Engineering',
            'Topic :: System',
            'Topic :: Software Development',
          ],
        setup_requires = ['numpy>=1.9'],
        packages = getpypkgs(),
        ext_modules = getpyexts(),
        py_modules = getpymods(),
)
